แพคเกจนี้สมารถทำให้คุณรู้จักMySmollมากขึ้น
==========================================

PyPi: https://pypi.org/project/MySmoll/

สวัสดีจ้าาาา แพ็คนี้คือแพ็คเกจที่จะทำให้คุณรู้จักMySmollมากขึ้น ###
วิธีติดตั้ง

เปิด CMD / Terminal

.. code:: python

   pip install MySmoll

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from MySmoll.Smoll import MySmoll

   MySmoll = MySmoll()
   MySmoll.show_name()
   MySmoll.show_art()
